@@ -12,6 +12,14 @@ def _signed_int(edt):  # signed ints
     return int.from_bytes(edt, byteorder="big", signed=True)
 
 
+def _hh_mm(edt):  # basic time unit
+    hh = int.from_bytes(edt[0:1], "big")
+    mm = int.from_bytes(edt[1:2], "big")
+    return f"{hh}:{mm}"
+
+def _to_string(edt):
+    return edt.decode('utf-8')
+
 # Check status of Echonnet Instance
 # ----------------- EPC SUPER FUNCTIONS -----------------------------
 def _0080(edt):
